@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from zope.i18nmessageid import MessageFactory
+import utils
 
 VPMessageFactory = MessageFactory('varnishpurger')
 
@@ -7,3 +8,4 @@ def initialize(context):
     """
     Initializer called when used as a Zope 2 product.
     """
+    utils.installWrapper()
\ No newline at end of file
